@@ -28,7 +28,7 @@ def setup(cfg):
         "decoder.exe",
         "chromactivate.exe",
         "sb-hd-bmp.bmp",
-        # r"C:\ProgramData\chocolatey\lib\NSSM\tools\nssm.exe",
+        r"C:\ProgramData\chocolatey\lib\NSSM\tools\nssm.exe",
     ]
 
     for file in files:
