@@ -134,7 +134,7 @@ def main(cfg):
 
     cmd_candle4 = [
         "candle",
-        str(bundle.with_suffix(".wxs")),
+        str(product.with_suffix(".wxs")),
         "-out",
         str(bundle.with_suffix(".wixobj")),
         "-ext",
