@@ -14,7 +14,4 @@ def test_with_initialize() -> None:
                 r"bin_path=C:\Users\Administrator\Downloads\streambox_iris-master"
             ],
         )
-        assert (
-            cfg.app.bin_path
-            == r"C:\Users\Administrator\Downloads\streambox_iris-master"
-        )
+        assert cfg.bin_path == r"C:\Users\Administrator\Downloads\streambox_iris-master"
